==> production-demo-20260209_092157.tar.gz: var/www/html/production-demo/var/tmp/twig/4a/4acda2253d20db5c9e6eec29694a6be0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/system/CoreBundle/Assets/img/logo-cut.png */
class __TwigTemplate_931c58b3895d580256dc4aaaf805255f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000G\000\0005\000\000\000ܩ^=\000\000.IDATx^uH6@\t2aL\t2&\teBPPL\000|%@xFIB_\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000owͿͻ῟?Mi\000`2E
y~<]^\000 H-?H;*\000:@4(cV~*\000(P}MuES;UW\000BSa͡F
\000@;5VF'(Bhya*]Oe\000_(ݨПFPѥ%\000я)F@neS?MV#7KɝR,=OY@LTY^ϐ\\vǟF\000ؽLnTJ8\000.{-9u\\ռKd(\000X\"pJ\000,mVɾ(y.\000Syj{7\000p9}D<\000R;JԽ̴dɱJ\0006W/8D2I\000Kϱϛ\$⬾!-~rL:6O\000bW{8Un\000EDIۗT\000ؘ7M֖,E)DV\"\t`E\"\"\t`-E\"ی\"\t`)EvE\\W|(D}\000aF@)e;n\\k>D\"m\000M\$MN^_\000xCHo}E\"ɣ\tBkp),OrH]f
MD˽Q\$ 4+r*׎zkm?yѰ
DY4Љ\\H~-b\tE\"@\"׽h,HVY&\"+\$ft\\X,EVUvmȶr,B4]ȦYXJ;\"tڦـF%,LȮc
i4 \\Η~fm#~o)7ܤq#r芎B-HWg틩xYi~t_-O[@љ\"/hTW8y FiGQρ碩l,h)f
xGQBTч<GԘuy֏7SUEbh3K*닄l;櫡t뺩k<!OW=hU^CM_U|4jCN [J)~hFmV(m3p1nJj,Fŵh1BRVmBDR}
ɡ!rCozv׍W@4
Nrn?#,K!
Ҿ)`N/C
Q h%bvo+ɢ\t)j9%bih9`
1u+R)7SKoAapy_%lh<*@@HM
(bI3Gۢ0Z\"\"bP\$lh(I4SH.ьhMu)@u(fAQD6\000!
\$Xh\\Ȯ-l&9]<h2w
r}E{Z)]l07/<c'\t04Gp7HHΏ\txz\$*n&F\\rQ7kyž6
\$BcUh?
\\h׹'pKjoL-p
i?~k\"]Π-E2Qp<E
HWƳp<Ob`bEE^X<y]lGxNV,ٿ6\\X`{QpKaLҜJC}=/V;V]uWG`E&Zӽ>vRc#>f;7FId/JٻG}'Y)
w4`_hV/AOOEiWѠM2\00097 GJ@v>3.
/v>Qk5׀@bZ>}} ?/cuad}}D+gͿMc%[-ġX
\$w48.oFa|Rℝ뇆GNn1H-q]ІǢ0.@~l<
#

:ؙA#'s((<~l0&@z5v16]ͶNmLQF0f@zkl7JWQP =l>Ft\\~')/gLY{J
RC%MҬOҴF6EK_mf>tPww
SMQdyħ+~P[M)Oy}\\`Q\";81T=K!Խ89tũ-^&tAR}gJ>.>13oϦۧ++9+ou%vhݡezl<,=cbfl֯pC)nSe?x^cWHloOorJs( 7VN
H09MY{2^c/z2|SX.]du9e\$cu:?W̱Ӄ9^33;a؆DeLܦR6%8i
+ӶmG>
&܎c.xFS{cp&fdЀeG.#D[c7I(\"\"iiM2)#ߏ5^
EQIZIVsIm{>Eu8S%\"i)1\$J?jh1ݹB-u^I?y\$?\$5ϳESF.?~ck%5d~Y~V(A5\$n{9٣f~zqܣFt2I-)%)Ƕ4zeY9TBJ=jt/sS2OQ\$23Hc519E2s\" k?_I<jtMאL-کNNXGY3J5fQ>Ӥ|ҷ:m*dfyuMF&ﲛTR+Ӕad\t͜Swl0>h?Wvg'K!L}C}lE>ۥ??&cvo=Wmr\t??;IMw#'I&}uv\$7I͋g\"^rZa\$;F[iLdyx'ȫQEŴ-+Rm
]08Q ]+Msܚl#V\"\\Ea\$ŵWKs𤈛t)BB#@gif+.0Q ]!|R-l\$TCŒ<8i&ɉO#Ij2\\#4fcH=+.01|H#Q(DH*eѯC]NKC;Hnmp\"ChLޕ&REY׍c\t&
\$ٞdMcݜ<-E]FgJsq<'7iЋZ։|d[:\\{ }\"l=J/%|}ȵGZ~3f+vH1zG*[Bj|)&\"A-Wqdj-4Sjv3RJSzտ̒G
`L9q?B&2y*|Sk49Ԏ>#EZy֟WS6e2fWrǐd?>~\"lݔb+tOݓO;V
/8wgI/U~ǁjR<uHi mL͙n\$TwwEp)|ߋM2c}ؙ4Ysx.oKys`\t%9d:\$ʡ=;\\6ww6}N%l~}k2#8IGY6IR)_K鵜F}쩷_qFKҧ4F\tO;Ϭn=h3'4KS%Ǥ)OBQsR7#'kLIr<:94ٟ.N΢H1s_]j Og<ѵ7XhEcIW'~k733X6.ɛ\t3L)J#r:bĿ.9'վX6eNeI{}\\_bu۹\t|kTd_+g.h-iOyɔ\t̻Q\$Ww+MCח9exJn_%`sx4z_\"+CLc-9EN\\Ө\$7:֟9;F#\t5}Q|\"B}G)ה[F\tľu4Gy;څ&|oǷK'=PvK{t}9+1\tV,i~{èE)1Reۖ}jgsu㉬_鳋MSiČƦ~(^\$%</Ή4j垸~UX!AwԵFF&iN[Mi{_XϛU?ƣ0<;fǕI%7*v#uiܺy#Гe.#7Bzċ&v
E7MPYm7cן7J+E9&D݈mB7ckv{O%>woɡ}-JP[͉G6
HL7bOT!Cr9q,̩>YY=oNMxWZ }o\$Cbf©P&}gfdl6%]zMJ0:8
QߎBbFȶ<})/)L\000(LHݦȘVi5٦Ogw\t+ֶeESjFH@>YIR3LozdC\\7o'x-Z!\\?*
V2\\߬ EE3_z=9[C6rq+,Nsmh/?kFMW-hbDčh_L;OQ#:F\$B_Jן547
F=>YXeڒ5+p%G,_W~7^鞊k(z+F@y|KuQY=*>V| b\tm!ܓRl\"}Nޡg4^@n)7q\t|.jMu)j/gpRI̸|mn%NN1MT\tc}./\$FGMqSk28=|dezk=T?/|jMqz%M>\\(ÂMD.ϚMU%ɸ\\kh/gͦ
+#ǵn\\~1\t9}GXx{RB7?\$\t-PyF\\+HDhBG.\\)Bbna5(r%A8ZG(\t{-IO\"[N{j6(&?\"GgKK%l5a/O({͓aB8&ov_Jdq[G؛(B\"J#MTq{uF#U\\&8~UVHv:DGWa#HUGp
G(&)dWQM4&+Sɮ8ZhLWcp^l5u{ZY&hao߫7Rɾpa^E^GHq\$J{j^(PaW7zzp=8DՄ&?~O?+\\\"씳L{jDPa#ntsJdI~/[M؛h1<]^8|rGPzV^8GȖ8ZG
G#w!1apa/ɋbpLp#v8ZGxʡpewQCqWyUη?/|Q#rbY\t|cTa\"%P-\$l_Fd/nP~Xc/\$DyQL\"wFX|)ɧ^1\tog12F8I<?/\t٭Ďh]aX6s~v~.pnڰKL9KeQ+g&t5>&|QBjxWL<=8&rj4V^|;Յ:48.I<9_Jo.I[8/=>YA
1BHoĎ=j*c5]?vOkMn)
\$nܻȱxI|{Q#u݄OYg(໸Љm}1яgGF!vBXhIѣ\"Kx߆[aMiP(mVĽ&*KP2-ܴ[֌v}\\Ʈ:-GLus-w-^Ѥ)\000ƐIvI_mKk[X]پ3\"*bc[bXS&׍Zp\$\\\\|A`+Z鵠i\$ss6 SLz
@~YeCȷy*
>Q;ն)xî {IW?
<|\"fmW~(w
|Y
}K37}JG[Y6ODw\"Mƶ{{k}{J֙7}Lc]!nhuMy~2S3_]E@P/,ٱ5{7H{0:+89:t8h޶#
V-H1ͺyѯEq[\"ih޶ͺy~qs>lӜ2&n1qe-|̘bѧ).cvs~㾴eđ//N=G
ϲl=l]m_V*+?<p]iW2AZ2ѣwܔE9x?}H_f)C~4u=z݌Fs%U F{~Q/H6(}λTa&~]\tww_;r16_il3^rkJJL
4ѧSl:h?qK܇!9c%%e5]}8Ѣsv7ڣPOgSۧ9EXR_t9D_>8=M_e2<V67)6E\tfzk~5W`pNZϩ-/)mw^>w֜Î47f3;KTu{f9w.M)EKBb'Q)sqH94*G},ڷ'M>_2\\F'YA8gFD_oC}ql@oΎ#W.N3[h!{<_ٓB[u֞N=d~(Ks
ћcGjQA4WMdZx#&bzmKw[:CeX!PMxDڔZ\$92X4Hyݕ-\\nehG˟UnLP%
2Ōhr\$9&l
˵7x:'d3rlwO\"QScǋ&=}1 SkNޯD.R)Ԛ'3=[Lۿ82Wc4}9}F#RҜʠ\$rFտOJƖ]kl
yA[GqSP>.+_,F΢A[hL#9iuB\"1B\"\t1FΖh:VɱYd\"iSnwoc0VS]Ac\"
\$IKϔOcHH0
\$Y?7\t\$9/RDat8fϣGZI.fQFrMR
\$\trlՈZ.5Iat&@+MsW5(JIm\000J!җ
\$\t
4b?7\t{ïp>8
\$5\000ͫToW.Ml;^\trF>\$jY7c8ʎ0QMX2E(dӱ\$VyZ/+H26GOG/IiЏGR))tOFe9٧fp}|EI8ziaBe)Ewu9<+MM!kB}?AߦʧaǨH*m,ߜT;͖nVVWL%\\Mѣ]}M'OY3fXvP#C:s-Ȳ1;T5FTeHm,E-r`Y\"G
H5fԈk)z{iF}v)[4OE\$N3juҽR5VͨEYxm9-W4Fܢ+avm/RT6'9FE'񔺈?K\\{+׿;-Ӄ>pSk%޽
REt\t4h|b~{)9Z1R(|qc.֋kWGʔH-bD;zP\$hEM>#FLߛfx)EQ|}FOϔ-_L(6 롾?lx%V6LyErcMkU,݊vG(6w-P\\LemP;U<BNu%}\000I,ôf4)7J])gFXywmoiyr{cvlG
P(Mю{8G蓘J؝P2v~ʔhgL\t%4vR8QvoH9tţziY6e#'lAOۯRvd+T/yag1ÓOF@
[T4}L]!-\0003+}xnby*R`M[zR?AW;{
w/;af88
^
6Osݢdx|_<?S\0000*c~f_OD,
\$`1i2z=XZd:r2W9`j#iwcl\tGat븲?B^@0c:4{_((ژNc=#'\\p;QiiuxRʕQ S1ƚq4GHF/1ƺG>HFoiGF|{)4F\000Q JJ9^\t8Z\$Gj
*lh_%|NelISnI*sr+Q8FNR;< 2zx ψm`UIT_aTG[cS<1Axf}FlSt ڊ=gqhԆ`4^]#`E4G̽'*/E_plh6LY=.ay

4lirlRS͘fiѴ&+@0V&Xvvp}鷲Od~S]}7u5򻔱({:'ڰ~HmOtf[`:F7J#aE-&cwĊQ\$Ѣk0b'mph57rbK.SF^62bq%]k]]1(Rd
i9GaxPʘj^;f5\0002q
B,
#i{Q'JۏtWQ[+*
#b2,/)7=ֿGR_4QWB!6m+DQ4yF6rҋ(=E,Q[א88EF(fq\$D)fGr]nc;>[\$iHn̽\$YKychx%(dtF}~o/]&
#i\\`dڜM1v{Ց~0\"'@ʌy*\\%y]Fc^\$.%Z1
#(DfMMiZ?m1տn~wt+=F~\"侽*R+SVm\$U=dSQ(% \\lϺG\"ve)3ѶbsGxG{wwYX5ő,eoJ::NYeX<sh(Þ~C]Я|?XSI_FLM&{R3'B/pD\">\000]`\\1+Ǯ{D*#?
2Tvکrݨ1133pv|Iע!ÛG7VAigHRSJMy
[z?L9unn?&=bꥨz*X\\،E#禜/rx^_3{X\"\"ǘF[i\t{h0&n\"\"{ϩwJ#?2OlSg#]f8Y(DDdk1ZKbӾx6R3Z˲&S-Y_4^`)\"4ur,+4d2esp
a#۫?`CG\"\"`

6G\"\"8Y,m_UhqMY.:ȤiE63aw@̑]}v`-\"\"צ[Uj?l<\"G\"\"ᷢi?~e#9vO-onRv[_}iɢBfrz)J3r?ڋbIdEĥ8Z),xF
J\"WhFHG\$e?Zo{E5dGؔMxoQׯԎ&՟E\$q4YCZ['Mz֡f-^YE2`ȋ'TZC;\$K9_ڕLËty>My%{ 1@]!qozL^S%>֯V/S\tǅϕ?wL^rO{>d2=\t%K_(؋H\t_/OR(ɺy.,;hm0Bi!SSՍkmpGI3ܚr!1rJ
[-^d,eʼ}8'I\\HAuL~3\$uގ
lF.Hs^FoHwڍI*sb`MO^<fnXF[3؟,g6ҏ=#iS1Ԟ݆etI~w`Tد峟
vu:LK<zs#@<TEw#)oi[M?Hɱ.@ps<Egĩ G\000G^FPm!Q(T7o_\000.xx.Dަ=+z\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000`9f%AT?u\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/system/CoreBundle/Assets/img/logo-cut.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/system/CoreBundle/Assets/img/logo-cut.png", "/var/www/html/mauticGIT-Test/themes/system/CoreBundle/Assets/img/logo-cut.png");
    }
}

==> production-demo-20260210_204327.tar.gz: var/www/html/production-demo/var/tmp/twig/4a/4acda2253d20db5c9e6eec29694a6be0.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/system/CoreBundle/Assets/img/logo-cut.png */
class __TwigTemplate_931c58b3895d580256dc4aaaf805255f extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000G\000\0005\000\000\000ܩ^=\000\000.IDATx^uH6@\t2aL\t2&\teBPPL\000|%@xFIB_\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000owͿͻ῟?Mi\000`2E
y~<]^\000 H-?H;*\000:@4(cV~*\000(P}MuES;UW\000BSa͡F
\000@;5VF'(Bhya*]Oe\000_(ݨПFPѥ%\000я)F@neS?MV#7KɝR,=OY@LTY^ϐ\\vǟF\000ؽLnTJ8\000.{-9u\\ռKd(\000X\"pJ\000,mVɾ(y.\000Syj{7\000p9}D<\000R;JԽ̴dɱJ\0006W/8D2I\000Kϱϛ\$⬾!-~rL:6O\000bW{8Un\000EDIۗT\000ؘ7M֖,E)DV\"\t`E\"\"\t`-E\"ی\"\t`)EvE\\W|(D}\000aF@)e;n\\k>D\"m\000M\$MN^_\000xCHo}E\"ɣ\tBkp),OrH]f
MD˽Q\$ 4+r*׎zkm?yѰ
DY4Љ\\H~-b\tE\"@\"׽h,HVY&\"+\$ft\\X,EVUvmȶr,B4]ȦYXJ;\"tڦـF%,LȮc
i4 \\Η~fm#~o)7ܤq#r芎B-HWg틩xYi~t_-O[@љ\"/hTW8y FiGQρ碩l,h)f
xGQBTч<GԘuy֏7SUEbh3K*닄l;櫡t뺩k<!OW=hU^CM_U|4jCN [J)~hFmV(m3p1nJj,Fŵh1BRVmBDR}
ɡ!rCozv׍W@4
Nrn?#,K!
Ҿ)`N/C
Q h%bvo+ɢ\t)j9%bih9`
1u+R)7SKoAapy_%lh<*@@HM
(bI3Gۢ0Z\"\"bP\$lh(I4SH.ьhMu)@u(fAQD6\000!
\$Xh\\Ȯ-l&9]<h2w
r}E{Z)]l07/<c'\t04Gp7HHΏ\txz\$*n&F\\rQ7kyž6
\$BcUh?
\\h׹'pKjoL-p
i?~k\"]Π-E2Qp<E
HWƳp<Ob`bEE^X<y]lGxNV,ٿ6\\X`{QpKaLҜJC}=/V;V]uWG`E&Zӽ>vRc#>f;7FId/JٻG}'Y)
w4`_hV/AOOEiWѠM2\00097 GJ@v>3.
/v>Qk5׀@bZ>}} ?/cuad}}D+gͿMc%[-ġX
\$w48.oFa|Rℝ뇆GNn1H-q]ІǢ0.@~l<
#

:ؙA#'s((<~l0&@z5v16]ͶNmLQF0f@zkl7JWQP =l>Ft\\~')/gLY{J
RC%MҬOҴF6EK_mf>tPww
SMQdyħ+~P[M)Oy}\\`Q\";81T=K!Խ89tũ-^&tAR}gJ>.>13oϦۧ++9+ou%vhݡezl<,=cbfl֯pC)nSe?x^cWHloOorJs( 7VN
H09MY{2^c/z2|SX.]du9e\$cu:?W̱Ӄ9^33;a؆DeLܦR6%8i
+ӶmG>
&܎c.xFS{cp&fdЀeG.#D[c7I(\"\"iiM2)#ߏ5^
EQIZIVsIm{>Eu8S%\"i)1\$J?jh1ݹB-u^I?y\$?\$5ϳESF.?~ck%5d~Y~V(A5\$n{9٣f~zqܣFt2I-)%)Ƕ4zeY9TBJ=jt/sS2OQ\$23Hc519E2s\" k?_I<jtMאL-کNNXGY3J5fQ>Ӥ|ҷ:m*dfyuMF&ﲛTR+Ӕad\t͜Swl0>h?Wvg'K!L}C}lE>ۥ??&cvo=Wmr\t??;IMw#'I&}uv\$7I͋g\"^rZa\$;F[iLdyx'ȫQEŴ-+Rm
]08Q ]+Msܚl#V\"\\Ea\$ŵWKs𤈛t)BB#@gif+.0Q ]!|R-l\$TCŒ<8i&ɉO#Ij2\\#4fcH=+.01|H#Q(DH*eѯC]NKC;Hnmp\"ChLޕ&REY׍c\t&
\$ٞdMcݜ<-E]FgJsq<'7iЋZ։|d[:\\{ }\"l=J/%|}ȵGZ~3f+vH1zG*[Bj|)&\"A-Wqdj-4Sjv3RJSzտ̒G
`L9q?B&2y*|Sk49Ԏ>#EZy֟WS6e2fWrǐd?>~\"lݔb+tOݓO;V
/8wgI/U~ǁjR<uHi mL͙n\$TwwEp)|ߋM2c}ؙ4Ysx.oKys`\t%9d:\$ʡ=;\\6ww6}N%l~}k2#8IGY6IR)_K鵜F}쩷_qFKҧ4F\tO;Ϭn=h3'4KS%Ǥ)OBQsR7#'kLIr<:94ٟ.N΢H1s_]j Og<ѵ7XhEcIW'~k733X6.ɛ\t3L)J#r:bĿ.9'վX6eNeI{}\\_bu۹\t|kTd_+g.h-iOyɔ\t̻Q\$Ww+MCח9exJn_%`sx4z_\"+CLc-9EN\\Ө\$7:֟9;F#\t5}Q|\"B}G)ה[F\tľu4Gy;څ&|oǷK'=PvK{t}9+1\tV,i~{èE)1Reۖ}jgsu㉬_鳋MSiČƦ~(^\$%</Ή4j垸~UX!AwԵFF&iN[Mi{_XϛU?ƣ0<;fǕI%7*v#uiܺy#Гe.#7Bzċ&v
E7MPYm7cן7J+E9&D݈mB7ckv{O%>woɡ}-JP[͉G6
HL7bOT!Cr9q,̩>YY=oNMxWZ }o\$Cbf©P&}gfdl6%]zMJ0:8
QߎBbFȶ<})/)L\000(LHݦȘVi5٦Ogw\t+ֶeESjFH@>YIR3LozdC\\7o'x-Z!\\?*
V2\\߬ EE3_z=9[C6rq+,Nsmh/?kFMW-hbDčh_L;OQ#:F\$B_Jן547
F=>YXeڒ5+p%G,_W~7^鞊k(z+F@y|KuQY=*>V| b\tm!ܓRl\"}Nޡg4^@n)7q\t|.jMu)j/gpRI̸|mn%NN1MT\tc}./\$FGMqSk28=|dezk=T?/|jMqz%M>\\(ÂMD.ϚMU%ɸ\\kh/gͦ
+#ǵn\\~1\t9}GXx{RB7?\$\t-PyF\\+HDhBG.\\)Bbna5(r%A8ZG(\t{-IO\"[N{j6(&?\"GgKK%l5a/O({͓aB8&ov_Jdq[G؛(B\"J#MTq{uF#U\\&8~UVHv:DGWa#HUGp
G(&)dWQM4&+Sɮ8ZhLWcp^l5u{ZY&hao߫7Rɾpa^E^GHq\$J{j^(PaW7zzp=8DՄ&?~O?+\\\"씳L{jDPa#ntsJdI~/[M؛h1<]^8|rGPzV^8GȖ8ZG
G#w!1apa/ɋbpLp#v8ZGxʡpewQCqWyUη?/|Q#rbY\t|cTa\"%P-\$l_Fd/nP~Xc/\$DyQL\"wFX|)ɧ^1\tog12F8I<?/\t٭Ďh]aX6s~v~.pnڰKL9KeQ+g&t5>&|QBjxWL<=8&rj4V^|;Յ:48.I<9_Jo.I[8/=>YA
1BHoĎ=j*c5]?vOkMn)
\$nܻȱxI|{Q#u݄OYg(໸Љm}1яgGF!vBXhIѣ\"Kx߆[aMiP(mVĽ&*KP2-ܴ[֌v}\\Ʈ:-GLus-w-^Ѥ)\000ƐIvI_mKk[X]پ3\"*bc[bXS&׍Zp\$\\\\|A`+Z鵠i\$ss6 SLz
@~YeCȷy*
>Q;ն)xî {IW?
<|\"fmW~(w
|Y
}K37}JG[Y6ODw\"Mƶ{{k}{J֙7}Lc]!nhuMy~2S3_]E@P/,ٱ5{7H{0:+89:t8h޶#
V-H1ͺyѯEq[\"ih޶ͺy~qs>lӜ2&n1qe-|̘bѧ).cvs~㾴eđ//N=G
ϲl=l]m_V*+?<p]iW2AZ2ѣwܔE9x?}H_f)C~4u=z݌Fs%U F{~Q/H6(}λTa&~]\tww_;r16_il3^rkJJL
4ѧSl:h?qK܇!9c%%e5]}8Ѣsv7ڣPOgSۧ9EXR_t9D_>8=M_e2<V67)6E\tfzk~5W`pNZϩ-/)mw^>w֜Î47f3;KTu{f9w.M)EKBb'Q)sqH94*G},ڷ'M>_2\\F'YA8gFD_oC}ql@oΎ#W.N3[h!{<_ٓB[u֞N=d~(Ks
ћcGjQA4WMdZx#&bzmKw[:CeX!PMxDڔZ\$92X4Hyݕ-\\nehG˟UnLP%
2Ōhr\$9&l
˵7x:'d3rlwO\"QScǋ&=}1 SkNޯD.R)Ԛ'3=[Lۿ82Wc4}9}F#RҜʠ\$rFտOJƖ]kl
yA[GqSP>.+_,F΢A[hL#9iuB\"1B\"\t1FΖh:VɱYd\"iSnwoc0VS]Ac\"
\$IKϔOcHH0
\$Y?7\t\$9/RDat8fϣGZI.fQFrMR
\$\trlՈZ.5Iat&@+MsW5(JIm\000J!җ
\$\t
4b?7\t{ïp>8
\$5\000ͫToW.Ml;^\trF>\$jY7c8ʎ0QMX2E(dӱ\$VyZ/+H26GOG/IiЏGR))tOFe9٧fp}|EI8ziaBe)Ewu9<+MM!kB}?AߦʧaǨH*m,ߜT;͖nVVWL%\\Mѣ]}M'OY3fXvP#C:s-Ȳ1;T5FTeHm,E-r`Y\"G
H5fԈk)z{iF}v)[4OE\$N3juҽR5VͨEYxm9-W4Fܢ+avm/RT6'9FE'񔺈?K\\{+׿;-Ӄ>pSk%޽
REt\t4h|b~{)9Z1R(|qc.֋kWGʔH-bD;zP\$hEM>#FLߛfx)EQ|}FOϔ-_L(6 롾?lx%V6LyErcMkU,݊vG(6w-P\\LemP;U<BNu%}\000I,ôf4)7J])gFXywmoiyr{cvlG
P(Mю{8G蓘J؝P2v~ʔhgL\t%4vR8QvoH9tţziY6e#'lAOۯRvd+T/yag1ÓOF@
[T4}L]!-\0003+}xnby*R`M[zR?AW;{
w/;af88
^
6Osݢdx|_<?S\0000*c~f_OD,
\$`1i2z=XZd:r2W9`j#iwcl\tGat븲?B^@0c:4{_((ژNc=#'\\p;QiiuxRʕQ S1ƚq4GHF/1ƺG>HFoiGF|{)4F\000Q JJ9^\t8Z\$Gj
*lh_%|NelISnI*sr+Q8FNR;< 2zx ψm`UIT_aTG[cS<1Axf}FlSt ڊ=gqhԆ`4^]#`E4G̽'*/E_plh6LY=.ay

4lirlRS͘fiѴ&+@0V&Xvvp}鷲Od~S]}7u5򻔱({:'ڰ~HmOtf[`:F7J#aE-&cwĊQ\$Ѣk0b'mph57rbK.SF^62bq%]k]]1(Rd
i9GaxPʘj^;f5\0002q
B,
#i{Q'JۏtWQ[+*
#b2,/)7=ֿGR_4QWB!6m+DQ4yF6rҋ(=E,Q[א88EF(fq\$D)fGr]nc;>[\$iHn̽\$YKychx%(dtF}~o/]&
#i\\`dڜM1v{Ց~0\"'@ʌy*\\%y]Fc^\$.%Z1
#(DfMMiZ?m1տn~wt+=F~\"侽*R+SVm\$U=dSQ(% \\lϺG\"ve)3ѶbsGxG{wwYX5ő,eoJ::NYeX<sh(Þ~C]Я|?XSI_FLM&{R3'B/pD\">\000]`\\1+Ǯ{D*#?
2Tvکrݨ1133pv|Iע!ÛG7VAigHRSJMy
[z?L9unn?&=bꥨz*X\\،E#禜/rx^_3{X\"\"ǘF[i\t{h0&n\"\"{ϩwJ#?2OlSg#]f8Y(DDdk1ZKbӾx6R3Z˲&S-Y_4^`)\"4ur,+4d2esp
a#۫?`CG\"\"`

6G\"\"8Y,m_UhqMY.:ȤiE63aw@̑]}v`-\"\"צ[Uj?l<\"G\"\"ᷢi?~e#9vO-onRv[_}iɢBfrz)J3r?ڋbIdEĥ8Z),xF
J\"WhFHG\$e?Zo{E5dGؔMxoQׯԎ&՟E\$q4YCZ['Mz֡f-^YE2`ȋ'TZC;\$K9_ڕLËty>My%{ 1@]!qozL^S%>֯V/S\tǅϕ?wL^rO{>d2=\t%K_(؋H\t_/OR(ɺy.,;hm0Bi!SSՍkmpGI3ܚr!1rJ
[-^d,eʼ}8'I\\HAuL~3\$uގ
lF.Hs^FoHwڍI*sb`MO^<fnXF[3؟,g6ҏ=#iS1Ԟ݆etI~w`Tد峟
vu:LK<zs#@<TEw#)oi[M?Hɱ.@ps<Egĩ G\000G^FPm!Q(T7o_\000.xx.Dަ=+z\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000\000`9f%AT?u\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/system/CoreBundle/Assets/img/logo-cut.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/system/CoreBundle/Assets/img/logo-cut.png", "/var/www/html/production-demo/themes/system/CoreBundle/Assets/img/logo-cut.png");
    }
}
